Crate montycat_serialization_derive

Crate montycat_serialization_derive 

Derive Macros

BinaryConvert
This procedural macro derives a trait called BinaryConvert for the struct it’s applied to. The BinaryConvert trait provides methods to convert a struct to and from its byte representation, useful for serializing and deserializing to and from binary formats.
RuntimeSchema